@@ -1,4 +1,7 @@
 package HTTP::Body::MultiPart;
+BEGIN {
+  $HTTP::Body::MultiPart::VERSION = '1.08';
+}
 
 use strict;
 use base 'HTTP::Body';
@@ -270,7 +273,9 @@ sub handler {
             $part->{filename} = $filename;
 
             if ( $filename ne "" ) {
-                my $fh = File::Temp->new( UNLINK => 0, DIR => $self->tmpdir );
+                my $suffix = $filename =~ /[^.]+(\.[^\\\/]+)$/ ? $1 : q{};
+
+                my $fh = File::Temp->new( UNLINK => 0, DIR => $self->tmpdir, SUFFIX => $suffix );
 
                 $part->{fh}       = $fh;
                 $part->{tempname} = $fh->filename;
