@@ -1,4 +1,7 @@
 package HTTP::Body::XForms;
+BEGIN {
+  $HTTP::Body::XForms::VERSION = '1.08';
+}
 
 use strict;
 use base 'HTTP::Body';
@@ -35,6 +38,8 @@ the buffer content.
 sub spin {
     my $self = shift;
 
+    return unless $self->length == $self->content_length;
+
     $self->body($self->{buffer});
     $self->param( 'XForms:Model', $self->{buffer} );
     $self->{buffer} = '';
